pub struct BackendStatus {
pub namespace: String,
pub healthy: bool,
pub last_checked_at: Option<DateTime<Utc>>,
pub consecutive_failures: u32,
pub error: Option<String>,
pub transport: Option<String>,
}Expand description
Health status of a single backend, updated by the background health checker.
Fields
namespace: StringBackend namespace (e.g. “db/”).
healthy: boolWhether the backend responded to the last health check.
last_checked_at: Option<DateTime<Utc>>Timestamp of the last health check.
consecutive_failures: u32Number of consecutive failed health checks.
error: Option<String>Last error message from a failed health check.
transport: Option<String>Transport type (e.g. “stdio”, “http”).