pub type MetricsHandle = Option<PrometheusHandle>;Expand description
Metrics handle type – wraps the Prometheus handle when the feature is enabled.
Aliased Type
pub enum MetricsHandle {
None,
Some(PrometheusHandle),
}pub type MetricsHandle = Option<PrometheusHandle>;Metrics handle type – wraps the Prometheus handle when the feature is enabled.
pub enum MetricsHandle {
None,
Some(PrometheusHandle),
}