pub struct OutlierDetectionConfig {
pub consecutive_errors: u32,
pub interval_seconds: u64,
pub base_ejection_seconds: u64,
pub max_ejection_percent: u32,
}Expand description
Passive health check / outlier detection configuration.
Tracks consecutive errors on live traffic and ejects unhealthy backends.
Fields
consecutive_errors: u32Number of consecutive errors before ejecting (default: 5)
interval_seconds: u64Evaluation interval in seconds (default: 10)
base_ejection_seconds: u64How long to eject in seconds (default: 30)
max_ejection_percent: u32Maximum percentage of backends that can be ejected (default: 50)