pub type SharedDiscoveryIndex = Arc<RwLock<DiscoveryRegistry>>;Expand description
Shared discovery index, wrapped for concurrent access from tool handlers.
Aliased Type
pub struct SharedDiscoveryIndex { /* private fields */ }pub type SharedDiscoveryIndex = Arc<RwLock<DiscoveryRegistry>>;Shared discovery index, wrapped for concurrent access from tool handlers.
pub struct SharedDiscoveryIndex { /* private fields */ }