pub struct OutlierDetectionLayer { /* private fields */ }Expand description
A Tower Layer that applies outlier detection to a backend.
Implementations
Sourceimpl OutlierDetectionLayer
impl OutlierDetectionLayer
Sourcepub fn new(
name: String,
config: OutlierDetectionConfig,
detector: OutlierDetector,
) -> Self
pub fn new( name: String, config: OutlierDetectionConfig, detector: OutlierDetector, ) -> Self
Create a new outlier detection layer for a specific backend.