Tool aliasing middleware for the proxy.
Rewrites tool names in list responses and call requests based on per-backend alias configuration.
Structs
- Alias
Map - Resolved alias mappings for all backends.
- Alias
Service - Tower service that rewrites tool names based on alias configuration.